/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: 7105_PLASTPO.SQL (CONSPLAN_GERAL BACKGROUND)

Descrio:
Clculo do Consumo Planejado Consolidado
(Cardpio, Consumo por Servio Fixo ou
Percapita) e gravao na tabela CONSPLAN.

P_NRLISTA      - Nmero da Lista de Servios
P_DTINICIAL    - Data inicial
P_DTFINAL      - Data final
P_IDPRODUTOS   - Identificador dos produtos a serem gravados.
                 Formato "XXX"
                 1 posio = "C" -> Cardpio
                 2 posio = "F" -> Consumo por Servio Fixo
                 3 posio = "P" -> Consumo por Servio Percapita
P_IDSEPPRATO   - Identificador de requisio analtica, ou seja, separada
                 por prato ou por setor, consumo fixo e consumo percapita.
                 Formato "S" (setor), "P" (prato) ou "N" (n/a).
P_PEACRESCIMO  - Percentual de acrscimo
P_IDARREDOND   - Identificador de utilizao do arredondamento
                 para requisio do Produto. Formato
                    S - ARREDONDAMENTO DE REQUISIO
                    N - NAO ARREDONDAR
                    C - ARREDONDAMENTO DE COMPRAS
P_CDPRODUTOINI - Cdigo do Produto inicial
P_CDPRODUTOFIN - Cdigo do Produto final
P_CDOPERADOR   - Cdigo do Operador
P_NRCONSPLANTH - Nuremo do proximo codigo, quando acionado segundo plano BACKGROUND 
P_NRCONSPLAN   _ NOVOCODIGO no formato 'P000000001'. (CDCONTADOR = CONSPLANPREV, nico para todas as filiais)

*/

CREATE OR REPLACE PROCEDURE CONSPLAN_GERAL
  (P_NRLISTA      IN VARCHAR2,
   P_DTINICIAL    IN DATE,
   P_DTFINAL      IN DATE,
   P_IDPRODUTOS   IN VARCHAR2,
   P_IDSEPPRATO   IN VARCHAR2,
   P_PEACRESCIMO  IN NUMBER,
   P_IDARREDOND   IN VARCHAR2,
   P_CDPRODUTOINI IN VARCHAR2,
   P_CDPRODUTOFIN IN VARCHAR2,
   P_CDOPERADOR   IN VARCHAR2,
   P_NRCONSPLANTH IN VARCHAR2,
   P_NRCONSPLAN   OUT VARCHAR2) IS

   V_CDARVINI     VARCHAR2(20);
   V_CDARVFIN     VARCHAR2(20);

   V_SERVICOS CLOB;
   V_PRXCONSPLAN VARCHAR2(20);
   V_NRCONSPLAN VARCHAR2(10);
   V_QTCARACTER   NUMBER;
BEGIN
   V_CDARVINI := P_CDPRODUTOINI;

   SELECT LENGTH(CDPICTPROD) - (SELECT MAX(CDNVPRODUTO) - 1 FROM PRODUTO)
   INTO   V_QTCARACTER
   FROM   PARAMGERAL
   WHERE  CDPARGERAL = '0001';
   V_CDARVFIN := RPAD(P_CDPRODUTOFIN, V_QTCARACTER, 'z');

   IF (P_NRCONSPLANTH = 'GERANOVCOD') THEN
      V_NRCONSPLAN := '_';
      NOVO_CODIGO('CONSPLANPREV', V_PRXCONSPLAN);
      V_NRCONSPLAN := 'P'||SUBSTR(V_PRXCONSPLAN,12,9);
   ELSE
      V_NRCONSPLAN := P_NRCONSPLANTH;
   END IF;

   FOR CUR_FILIAL IN
      (SELECT
          DISTINCT SUBSTR(LISTA.CDLISTA, 1, 4) AS CDFILIAL
       FROM
          LISTA
       WHERE
          (LISTA.NRLISTA = P_NRLISTA))
   LOOP
      V_SERVICOS := '_';
      FOR CUR_SERVICO IN
         (SELECT
             SUBSTR(CDLISTA, 5, 5) AS CDSERVFILI
          FROM
             LISTA
          WHERE
             NRLISTA = P_NRLISTA AND
             SUBSTR(CDLISTA, 1, 4) = CUR_FILIAL.CDFILIAL
          )
      LOOP
         V_SERVICOS := V_SERVICOS || CUR_SERVICO.CDSERVFILI || '_';
      END LOOP;

      CONSUMO_PLANEJADO_PLA(CUR_FILIAL.CDFILIAL,
                            V_SERVICOS,
                            P_DTINICIAL,
                            P_DTFINAL,
                            'C',   /* GRAVAO NA TABELA CONSPLAN */
                            P_IDPRODUTOS, /* CARDPIO, CONSUMO FIXO E PERCAPITA */
                            P_IDSEPPRATO,   /* FOI INCLUDO O PARMETRO P_IDSEPPRATO */
                            P_PEACRESCIMO,
                            P_IDARREDOND,
                            V_NRCONSPLAN,
                            V_CDARVINI,
                            V_CDARVFIN,
                            P_CDOPERADOR,
                            '',
                            '');

      COMMIT;
   END LOOP;
   P_NRCONSPLAN := V_NRCONSPLAN;
   DELETE FROM LISTA WHERE NRLISTA = P_NRLISTA;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('CONSPLAN_GERAL','0.00.000'); END;
/

